/*
    itdb-files - Dump out names of files from the iTunes database
    Copyright (C) 2006 Richard Dawe

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <gpod/itdb.h>

static void
list_files (Itdb_iTunesDB *itunes)
{
  const int n_tracks = itdb_tracks_number(itunes);
  int i;

  for (i = 0; i < n_tracks; ++i)
    {
      Itdb_Track *track = g_list_nth_data(itunes->tracks, i);
      char *track_path = itdb_filename_on_ipod(track);

      if (track_path)
	{
	  puts(track_path);
	  free(track_path);
	}
    }
}

int
main (int argc, char *argv[])
{
  Itdb_iTunesDB *itunes = NULL;
  char *ipod_path = NULL;
  GError *err = NULL;
  int ok = 1;

  if (argc > 1)
    ipod_path = argv[1];
  else
    ok = 0;

  if (ok)
    itunes = itdb_parse(ipod_path, &err);
  if (err != NULL)
    {
      fprintf (stderr, "Unable to open iTunes database: %s\n", err->message);
      g_error_free (err);
      ok = 0;
    }

  if (ok)
    list_files(itunes);

  return ok ? EXIT_SUCCESS : EXIT_FAILURE;
}
